==> xmobar-0.50-120-riscv64.pkg.tar.zst: usr/share/haskell/register/xmobar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmobar
version:              0.50
visibility:           public
id:                   xmobar-0.50-4qhLqEP4PVM8BC1XfvYquJ
key:                  xmobar-0.50-4qhLqEP4PVM8BC1XfvYquJ
license:              BSD-3-Clause
maintainer:           Jose A. Ortega Ruiz <jao@gnu.org>
author:               Andrea Rossato and Jose A. Ortega Ruiz
homepage:             https://codeberg.org/xmobar/xmobar
synopsis:             A Minimalistic Text Based Status Bar
description:
    Xmobar is a minimalistic text based status bar.

    Inspired by the Ion3 status bar, it supports similar
    features, like dynamic color management, output templates,
    and extensibility through plugins.

category:             System
abi:                  d020c5863ecff068723832d965db6a51
exposed:              True
exposed-modules:
    Xmobar Xmobar.Plugins.Accordion Xmobar.Plugins.Monitors.Common
    Xmobar.Plugins.Monitors.Common.Run
    Xmobar.Plugins.Monitors.Common.Types Xmobar.Plugins.Monitors.Cpu

hidden-modules:
    Paths_xmobar Xmobar.Config.Types Xmobar.Config.Parse
    Xmobar.Config.Template Xmobar.Run.Types Xmobar.Run.Timer
    Xmobar.Run.Template Xmobar.Run.Exec Xmobar.Run.Runnable
    Xmobar.Run.Actions Xmobar.Run.Loop Xmobar.Draw.Boxes
    Xmobar.Draw.Cairo Xmobar.Draw.Types Xmobar.App.Config
    Xmobar.App.Main Xmobar.App.Opts Xmobar.App.Compile
    Xmobar.System.Utils Xmobar.System.StatFS Xmobar.System.Environment
    Xmobar.System.Localize Xmobar.System.Signal Xmobar.System.Kbd
    Xmobar.Text.Ansi Xmobar.Text.Loop Xmobar.Text.Pango
    Xmobar.Text.Swaybar Xmobar.Text.SwaybarClicks Xmobar.Text.Output
    Xmobar.X11.Bitmap Xmobar.X11.CairoSurface Xmobar.X11.ColorCache
    Xmobar.X11.Draw Xmobar.X11.Events Xmobar.X11.Loop Xmobar.X11.Text
    Xmobar.X11.Types Xmobar.X11.Window Xmobar.Plugins.ArchUpdates
    Xmobar.Plugins.Command Xmobar.Plugins.BufferedPipeReader
    Xmobar.Plugins.CommandReader Xmobar.Plugins.Date
    Xmobar.Plugins.EWMH Xmobar.Plugins.HandleReader
    Xmobar.Plugins.QueueReader Xmobar.Plugins.PacmanUpdates
    Xmobar.Plugins.PipeReader Xmobar.Plugins.MarqueePipeReader
    Xmobar.Plugins.StdinReader Xmobar.Plugins.XMonadLog
    Xmobar.Plugins.Kbd Xmobar.Plugins.Locks Xmobar.Plugins.NotmuchMail
    Xmobar.Plugins.Monitors Xmobar.Plugins.Monitors.Batt
    Xmobar.Plugins.Monitors.Batt.Common
    Xmobar.Plugins.Monitors.Common.Output
    Xmobar.Plugins.Monitors.Common.Parsers
    Xmobar.Plugins.Monitors.Common.Files
    Xmobar.Plugins.Monitors.CoreTemp Xmobar.Plugins.Monitors.K10Temp
    Xmobar.Plugins.Monitors.Cpu.Common Xmobar.Plugins.Monitors.CpuFreq
    Xmobar.Plugins.Monitors.Disk Xmobar.Plugins.Monitors.Disk.Common
    Xmobar.Plugins.Monitors.Load Xmobar.Plugins.Monitors.Load.Common
    Xmobar.Plugins.Monitors.Mem Xmobar.Plugins.Monitors.MultiCoreTemp
    Xmobar.Plugins.Monitors.MultiCpu Xmobar.Plugins.Monitors.Net
    Xmobar.Plugins.Monitors.Net.Common Xmobar.Plugins.Monitors.Swap
    Xmobar.Plugins.Monitors.Thermal Xmobar.Plugins.Monitors.ThermalZone
    Xmobar.Plugins.Monitors.Top Xmobar.Plugins.Monitors.Top.Common
    Xmobar.Plugins.Monitors.Uptime Xmobar.Plugins.Monitors.Bright
    Xmobar.Plugins.Monitors.CatInt Xmobar.X11.XRender
    Xmobar.Plugins.Mail Xmobar.Plugins.MBox
    Xmobar.Plugins.Monitors.Wireless Xmobar.Plugins.Monitors.MPD
    Xmobar.Plugins.Monitors.Volume Xmobar.Plugins.Monitors.Alsa
    Xmobar.Plugins.DateZone Xmobar.Plugins.Monitors.Mpris
    Xmobar.System.DBus Xmobar.X11.XPMFile
    Xmobar.Plugins.Monitors.Weather Xmobar.Plugins.Monitors.Batt.Linux
    Xmobar.Plugins.Monitors.Cpu.Linux
    Xmobar.Plugins.Monitors.Disk.Linux
    Xmobar.Plugins.Monitors.Load.Linux
    Xmobar.Plugins.Monitors.Mem.Linux Xmobar.Plugins.Monitors.Net.Linux
    Xmobar.Plugins.Monitors.Swap.Linux
    Xmobar.Plugins.Monitors.Top.Linux
    Xmobar.Plugins.Monitors.Uptime.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmobar-0.50
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmobar-0.50
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmobar-0.50
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/riscv64-linux-ghc-9.4.8/xmobar-0.50
hs-libraries:         HSxmobar-0.50-4qhLqEP4PVM8BC1XfvYquJ
extra-libraries:      Xrandr Xrender Xpm
depends:
    X11-1.10.3-296FmCDygJo4Xo4fAuEwJZ
    X11-xft-0.3.4-KDDg7VHuM1h3G3OtpeQ0sv
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk
    alsa-core-0.5.0.1-JLPmRcHiZRx1HOkmXNRClE
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u
    async-2.2.5-GGvJE1nOBFYGFw0FXsPFU0 base-4.17.2.1
    bytestring-0.11.5.3 cairo-0.13.12.0-EK2nm68HmFdAWU4se40pHT
    cereal-0.5.8.3-H9MXf6i1TMkEAfnsx4oYbT
    colour-2.3.6-Es9wrqLKeClLAeJW79jO2p containers-0.6.7
    dbus-1.3.3-LpDQHaNyiML1MRcclv9sum directory-1.3.7.1
    extensible-exceptions-0.1.1.4-AGheGT2ZUDiCzp52FHEfjQ
    extra-1.7.16-CyTEZvSfBxsKCwY9ZtJE7E filepath-1.4.2.2
    hinotify-0.4.2-Bi6WhcL9fCKI2Q94FqV1ys
    http-client-tls-0.3.6.4-Fuw6mDzbeZhIZH9nOSD8AM
    http-conduit-2.3.9.1-Jt8i9zz8puP9BUVEul6uLX
    http-types-0.12.4-3Rkn4NOOYhzvBVdRap5Ii
    libmpd-0.10.0.1-9OthOA6VlucIkGE4BiUSCd mtl-2.2.2
    netlink-1.1.1.0-EtwuQcOdMkCK92FWbMUZBF
    old-locale-1.0.0.7-KCPcWVOQKME2P4y4gxzvhh
    pango-0.13.11.0-F8Zu5B0KBzd5PAbhkZDgbp parsec-3.1.16.1
    parsec-numbers-0.1.0-IKvzIVbeZPOFD4DHi1QStS process-1.6.18.0
    regex-compat-0.95.2.2-XQpODnagAHFJ9GlOSqau8 stm-2.5.1.0 time-1.12.2
    timezone-olson-0.2.1-BTp5R7q1AJdEnV7pV8RSLq
    timezone-series-0.1.13-21o0dMYZobR86i3h6j9FWj transformers-0.5.6.2
    unix-2.7.3 utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:
    /usr/share/doc/riscv64-linux-ghc-9.4.8/xmobar-0.50/html/xmobar.haddock

haddock-html:         /usr/share/doc/riscv64-linux-ghc-9.4.8/xmobar-0.50/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmobar-0.50-129-riscv64.pkg.tar.zst: usr/share/haskell/register/xmobar.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmobar
version:              0.50
visibility:           public
id:                   xmobar-0.50-IGTysALJmGj6b99sLdnZzN
key:                  xmobar-0.50-IGTysALJmGj6b99sLdnZzN
license:              BSD-3-Clause
maintainer:           Jose A. Ortega Ruiz <jao@gnu.org>
author:               Andrea Rossato and Jose A. Ortega Ruiz
homepage:             https://codeberg.org/xmobar/xmobar
synopsis:             A Minimalistic Text Based Status Bar
description:
    Xmobar is a minimalistic text based status bar.

    Inspired by the Ion3 status bar, it supports similar
    features, like dynamic color management, output templates,
    and extensibility through plugins.

category:             System
abi:                  e4de417cb6771dcff803aced4f283ddf
exposed:              True
exposed-modules:
    Xmobar Xmobar.Plugins.Accordion Xmobar.Plugins.Monitors.Common
    Xmobar.Plugins.Monitors.Common.Run
    Xmobar.Plugins.Monitors.Common.Types Xmobar.Plugins.Monitors.Cpu

hidden-modules:
    Paths_xmobar Xmobar.Config.Types Xmobar.Config.Parse
    Xmobar.Config.Template Xmobar.Run.Types Xmobar.Run.Timer
    Xmobar.Run.Template Xmobar.Run.Exec Xmobar.Run.Runnable
    Xmobar.Run.Actions Xmobar.Run.Loop Xmobar.Draw.Boxes
    Xmobar.Draw.Cairo Xmobar.Draw.Types Xmobar.App.Config
    Xmobar.App.Main Xmobar.App.Opts Xmobar.App.Compile
    Xmobar.System.Utils Xmobar.System.StatFS Xmobar.System.Environment
    Xmobar.System.Localize Xmobar.System.Signal Xmobar.System.Kbd
    Xmobar.Text.Ansi Xmobar.Text.Loop Xmobar.Text.Pango
    Xmobar.Text.Swaybar Xmobar.Text.SwaybarClicks Xmobar.Text.Output
    Xmobar.X11.Bitmap Xmobar.X11.CairoSurface Xmobar.X11.ColorCache
    Xmobar.X11.Draw Xmobar.X11.Events Xmobar.X11.Loop Xmobar.X11.Text
    Xmobar.X11.Types Xmobar.X11.Window Xmobar.Plugins.ArchUpdates
    Xmobar.Plugins.Command Xmobar.Plugins.BufferedPipeReader
    Xmobar.Plugins.CommandReader Xmobar.Plugins.Date
    Xmobar.Plugins.EWMH Xmobar.Plugins.HandleReader
    Xmobar.Plugins.QueueReader Xmobar.Plugins.PacmanUpdates
    Xmobar.Plugins.PipeReader Xmobar.Plugins.MarqueePipeReader
    Xmobar.Plugins.StdinReader Xmobar.Plugins.XMonadLog
    Xmobar.Plugins.Kbd Xmobar.Plugins.Locks Xmobar.Plugins.NotmuchMail
    Xmobar.Plugins.Monitors Xmobar.Plugins.Monitors.Batt
    Xmobar.Plugins.Monitors.Batt.Common
    Xmobar.Plugins.Monitors.Common.Output
    Xmobar.Plugins.Monitors.Common.Parsers
    Xmobar.Plugins.Monitors.Common.Files
    Xmobar.Plugins.Monitors.CoreTemp Xmobar.Plugins.Monitors.K10Temp
    Xmobar.Plugins.Monitors.Cpu.Common Xmobar.Plugins.Monitors.CpuFreq
    Xmobar.Plugins.Monitors.Disk Xmobar.Plugins.Monitors.Disk.Common
    Xmobar.Plugins.Monitors.Load Xmobar.Plugins.Monitors.Load.Common
    Xmobar.Plugins.Monitors.Mem Xmobar.Plugins.Monitors.MultiCoreTemp
    Xmobar.Plugins.Monitors.MultiCpu Xmobar.Plugins.Monitors.Net
    Xmobar.Plugins.Monitors.Net.Common Xmobar.Plugins.Monitors.Swap
    Xmobar.Plugins.Monitors.Thermal Xmobar.Plugins.Monitors.ThermalZone
    Xmobar.Plugins.Monitors.Top Xmobar.Plugins.Monitors.Top.Common
    Xmobar.Plugins.Monitors.Uptime Xmobar.Plugins.Monitors.Bright
    Xmobar.Plugins.Monitors.CatInt Xmobar.X11.XRender
    Xmobar.Plugins.Mail Xmobar.Plugins.MBox
    Xmobar.Plugins.Monitors.Wireless Xmobar.Plugins.Monitors.MPD
    Xmobar.Plugins.Monitors.Volume Xmobar.Plugins.Monitors.Alsa
    Xmobar.Plugins.DateZone Xmobar.Plugins.Monitors.Mpris
    Xmobar.System.DBus Xmobar.X11.XPMFile
    Xmobar.Plugins.Monitors.Weather Xmobar.Plugins.Monitors.Batt.Linux
    Xmobar.Plugins.Monitors.Cpu.Linux
    Xmobar.Plugins.Monitors.Disk.Linux
    Xmobar.Plugins.Monitors.Load.Linux
    Xmobar.Plugins.Monitors.Mem.Linux Xmobar.Plugins.Monitors.Net.Linux
    Xmobar.Plugins.Monitors.Swap.Linux
    Xmobar.Plugins.Monitors.Top.Linux
    Xmobar.Plugins.Monitors.Uptime.Linux

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/xmobar-0.50
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/xmobar-0.50
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/xmobar-0.50
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/riscv64-linux-ghc-9.6.7.20250817/xmobar-0.50
hs-libraries:         HSxmobar-0.50-IGTysALJmGj6b99sLdnZzN
extra-libraries:      Xrandr Xrender Xpm
depends:
    X11-1.10.3-HWgzJgi0fCl89s6WpBOoXu
    X11-xft-0.3.4-5xOLly5uGTD3oKWfNDpHqy
    aeson-2.2.0.0-C0AkopVKntgCgZgm8TP6Wj
    alsa-core-0.5.0.1-G9OCDHVUDN26AFLoLFWKH
    alsa-mixer-0.3.0.1-AiwYgS9BSzc5DsO2dz8PjB
    async-2.2.5-1ovq96REeQVKYsP5cduurl base-4.18.3.0
    bytestring-0.11.5.4 cairo-0.13.12.0-WsRl5c30Pb1liJZ4gKqMu
    cereal-0.5.8.3-KyriAjDATgO4cDDmhBOwvk
    colour-2.3.6-DoApLSa6gBO3p6mb77xRwR containers-0.6.7
    dbus-1.3.3-8ZPKLqe5BSTGs3HArkJibS directory-1.3.8.5
    extensible-exceptions-0.1.1.4-CNAlK8LvrH1EafsJXtad6L
    extra-1.7.16-6ZwXlNpxrkMIvGHgrs9GlE filepath-1.4.301.0
    hinotify-0.4.2-JhWAZt54mzc20xPFdMbWHK
    http-client-tls-0.3.6.4-HXUUJKGirCyJJRNpLsLsRH
    http-conduit-2.3.9.1-6NMT7isJoG35ZNJeS0m6Qu
    http-types-0.12.4-J3nJ0CyBWeuE063Mvy4vWu
    libmpd-0.10.0.1-D4cfsv0WxaL5QtVjuBtjO3 mtl-2.3.1
    netlink-1.1.1.0-4Rn9rHevUJgAP1w0scFnwh
    old-locale-1.0.0.7-HSvLS5bQrOr2jPp7CISS55
    pango-0.13.11.0-KTC6K0ZPQWt2j2AfQsIaDS parsec-3.1.16.1
    parsec-numbers-0.1.0-D2eT119pJB5LHd9omW8i9Y process-1.6.19.0
    regex-compat-0.95.2.2-K7oxv3y9MR6EkVpN6XHsIK stm-2.5.1.0
    time-1.12.2 timezone-olson-0.2.1-6A1EWDlrHKM884qymJbuh8
    timezone-series-0.1.13-8d0IG33wXXG2KpANMxKGJI transformers-0.6.1.0
    unix-2.8.6.0 utf8-string-1.0.2-shiuprzUpU7bW4pJ3bW0

haddock-interfaces:
    /usr/share/doc/riscv64-linux-ghc-9.6.7.20250817/xmobar-0.50/html/xmobar.haddock

haddock-html:
    /usr/share/doc/riscv64-linux-ghc-9.6.7.20250817/xmobar-0.50/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
